import matplotlib.pyplot as plt
import pandas as pd
import numpy as np

#Extraction des données des fichiers CSV :
spectreH=pd.read_csv("H41.csv", delimiter=',')
spectreHe=pd.read_csv("HeComplet.csv", delimiter=',')
spectreLi=pd.read_csv("Li41.csv", delimiter=',')
spectreK=pd.read_csv("K86.csv", delimiter=',')
spectreHg=pd.read_csv("Hg100.csv", delimiter=',')
spectreNa=pd.read_csv("Na101.csv", delimiter=',')
spectreZn=pd.read_csv("Zn.csv", delimiter=',')

#Données filtrées par intensité :
"""
Pour retirer les raies les moins intenses, augmenter
la valeur du multiplicateur (entre 0 et 1).
multiplicateur=0 : toutes les raies.
multiplicateur=1 : aucune raie.
"""
spectreHf=spectreH[spectreH["Aki"]>0.0*max(spectreH["Aki"])]
spectreHef=spectreHe[spectreHe["Aki"]>0.1*max(spectreHe["Aki"])]
spectreLif=spectreLi[spectreLi["Aki"]>0.1*max(spectreLi["Aki"])]
spectreKf=spectreK[spectreK["Aki"]>0.2*max(spectreK["Aki"])]
spectreHgf=spectreHg[spectreHg["Aki"]>0.1*max(spectreHg["Aki"])]
spectreNaf=spectreNa[spectreNa["Aki"]>0.1*max(spectreNa["Aki"])]
spectreZnf=spectreZn[spectreZn["Aki"]>0.0*max(spectreZn["Aki"])]

#-----------------------------------------------------------------------------------------
"""Définition d'une fonction qui trace le spectre d'un élément.
element est le nom (chaîne de caractères, entre "")
data est le tableau de données de cet élément.
"""
def trace(element, data):
    for L in np.linspace(350, 750, 250):#fond continu coloré
        plt.plot([L, L], [0, h], linewidth=10, c=cmap((L-350)/400))
    for L in data["wl"]:
        plt.plot([L, L], [0, h], linewidth=ep, c='black')    
    plt.ylabel(element, fontsize=18, rotation=0, ha='right')
    plt.yticks([])#supprime les graduations en y
    plt.xlim(350, 750)#limites de l'axe x
    plt.ylim(0, h)#limites de l'axe y
#    changer les intervalles de longueur d'onde :
#    plt.xticks(np.arange(400, 800, 100))#le dernier nombre est l'intervalle

#Paramètres du graphique :----------------------------------
h=30#hauteur des raies
ep=0.8#épaisseur des raies

fig=plt.figure(figsize=(7, 15))

plt.suptitle("Spectres d'absorption de quelques éléments")
cmap=plt.get_cmap('turbo')#gamme de couleurs du visible
#Attention, le colormap 'turbo' n'est pas inclus dans les installations
#matplotlib antérieures à la version 3.3.0
plt.subplots_adjust(top=0.92, bottom=0.06, left=0.1, right=0.95, hspace=0.5)

#GRAPHE 1 --------------------------------------------------------------------------
ax1=plt.subplot(711)
"""
Pour n'avoir qu'un seul spectre, supprimer les lignes de code
non souhaitées, et remplacer la ligne précédente par :
ax1=plt.subplot(111)
"""

plt.title("Données NIST : https://physics.nist.gov/asd", fontsize=8, loc='right')
trace("H", spectreHf)

#GRAPHE 2 --------------------------------------------------------------------------
ax2=plt.subplot(712)
trace("He", spectreHef)

#GRAPHE 3 --------------------------------------------------------------------------
ax3=plt.subplot(713)
trace("Li", spectreLif)

#GRAPHE 4 --------------------------------------------------------------------------
ax4=plt.subplot(714)
trace("K", spectreKf)

#GRAPHE 5 --------------------------------------------------------------------------
ax5=plt.subplot(715)
trace("Hg", spectreHgf)

#GRAPHE 6 --------------------------------------------------------------------------
ax6=plt.subplot(716)
trace("Na", spectreNaf)

#GRAPHE 7 --------------------------------------------------------------------------
ax7=plt.subplot(717)
trace("Zn", spectreZnf)
plt.xlabel("longueur d'onde (nm)")

#Création d'un fichier image :
fig.savefig("SpectresRaiesABSdpi200.png", dpi=200)
#Création d'un fichier pdf :
#fig.savefig("SpectresDeRaiesABSdpi200.pdf", dpi=200)
plt.show()
